import {Component} from '@angular/core'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorHandlingComponent} from '../../../../shared/components/subscribing.component'
import {Material} from '../../../../shared/model/material.model'
import {MaterialService} from '../../../../material/service/material.service'
import {MixService} from '../../../services/mix.service'
import {ErrorService} from '../../../../shared/service/error.service'
import {MixMaterialDto, Recipe} from '../../../../shared/model/recipe.model'
import {AlertService} from '../../../../shared/service/alert.service'
import {RecipeService} from "../../../services/recipe.service";

@Component({
  selector: 'cre-mix-edit',
  templateUrl: './mix-edit.component.html',
  styleUrls: ['./mix-edit.component.sass']
})
export class MixEditComponent extends ErrorHandlingComponent {
  mixId: number | null
  recipe: Recipe | null
  materials: Material[] | null

  private recipeId: number | null

  constructor(
    private recipeService: RecipeService,
    private materialService: MaterialService,
    private mixService: MixService,
    private alertService: AlertService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    super.ngOnInit()

    this.mixId = this.urlUtils.parseIntUrlParam('id')
    this.recipeId = this.urlUtils.parseIntUrlParam('recipeId')

    this.fetchRecipe()
    this.fetchMaterials()
  }

  private fetchRecipe() {
    this.subscribe(
      this.recipeService.getById(this.recipeId),
      recipe => this.recipe = recipe
    )
  }

  private fetchMaterials() {
    this.subscribe(
      this.materialService.getAllForMixUpdate(this.mixId),
      materials => this.materials = materials
    )
  }

  submit(values) {
    if(!this.mixMaterialsPositionAreValid(values.mixMaterials)) {
      this.alertService.pushError('Les ingrédients ne peuvent pas avoir une position inférieure à 1')
      return
    }

    this.subscribeAndNavigate(
      this.mixService.updateWithUnits(this.mixId, values.name, values.materialTypeId, values.mixMaterials),
      `/color/edit/${this.recipeId}`
    )
  }

  private mixMaterialsPositionAreValid(mixMaterials: MixMaterialDto[]): boolean {
    return !mixMaterials.find(m => m.position <= 0)
  }
}
